==> vengamo_chat_ui-1.3.4.tar.gz: lib/components/audio_widget.dart <==
import 'package:flutter/material.dart';
import 'package:vengamo_chat_ui/components/voice_wave/voice_message.dart';
import '../seen_status.dart';
import '../theme/app_color.dart';
import 'audio_placeholder.dart';
// ignore: depend_on_referenced_packages
import 'package:flutter_cache_manager/flutter_cache_manager.dart';

class AudioWidget extends StatelessWidget {
  const AudioWidget(
      {super.key,
      required this.isMe,
      required this.audioSource,
      required this.ack,
      required this.time,
      required this.timeLabelColor,
      required this.senderBgColor,
      required this.receiverBgColor,
      required this.isLoading,
      this.messageReplyBgColor,
      this.messageReplyBorderColor,
      this.messageReply});

  final bool isMe;
  final String audioSource;
  final Widget ack;
  final String time;
  final Color timeLabelColor;
  final Color senderBgColor;
  final Color receiverBgColor;
  final bool isLoading;
  final Color? messageReplyBgColor;

  /// the Border color applied to the message reply
  final Color? messageReplyBorderColor;

  /// message Reply
  final String? messageReply;

  bool isFileFromURL(String filePath) {
    if (filePath.startsWith('http://') || filePath.startsWith('https://')) {
      return true; //From URL
    } else {
      // local cached file
      return false;
    }
  }

  @override
  Widget build(BuildContext context) {
    return Padding(
      key: key,
      padding: const EdgeInsets.symmetric(horizontal: 8, vertical: 4),
      child: messageReply != null && messageReply != ""
          ? Column(
              mainAxisAlignment: MainAxisAlignment.start,
              crossAxisAlignment: CrossAxisAlignment.start,
              children: [
                Stack(
                  children: [
                    Container(
                      decoration: BoxDecoration(
                        color: messageReplyBgColor ??
                            (isMe
                                ? const Color(0xFFB3D19D).withOpacity(0.5)
                                : Colors.grey[300]),
                      ),
                      constraints: const BoxConstraints(maxHeight: 55),
                      child: Padding(
                        padding: const EdgeInsets.only(
                            left: 8, top: 3, bottom: 2, right: 2),
                        child: Row(
                          crossAxisAlignment: CrossAxisAlignment.start,
                          mainAxisAlignment: MainAxisAlignment.spaceBetween,
                          children: [
                            Column(
                              crossAxisAlignment: CrossAxisAlignment.start,
                              children: [
                                Text(isMe ? "Sent" : "Received"), // "Sent" text
                                const SizedBox(
                                    height:
                                        8), // Add space between "Sent" and photo icon
                                const Icon(
                                  Icons.mic_sharp,
                                  color: AppColors.iconColor,
                                ), // Photo icon
                              ],
                            ),
                            const SizedBox(
                                width:
                                    8), // Add space between photo icon and image

                            Padding(
                              padding: const EdgeInsets.all(8.0),
                              child: Center(
                                child: Container(
                                  decoration: BoxDecoration(
                                    shape: BoxShape.circle,
                                    color: isMe
                                        ? const Color.fromARGB(
                                            255, 175, 173, 173)
                                        : const Color(0xFF2BCA72),
                                  ),
                                  width: 35,
                                  height: 35,
                                  child: InkWell(
                                    onTap: () => {},
                                    child: Icon(
                                      Icons.play_arrow,
                                      color: messageReplyBorderColor ??
                                          (isMe
                                              ? senderBgColor
                                              : receiverBgColor),
                                      size: 25,
                                    ),
                                  ),
                                ),
                              ),
                            )
                            // The actual photo on the right
                          ],
                        ),
                      ),
                    ),
                    Positioned(
                      top: 0,
                      bottom: 0,
                      left: -1.5, // Adjust the value as needed for your design
                      child: Container(
                        decoration: BoxDecoration(
                          color: messageReplyBorderColor ??
                              (isMe ? const Color(0xFF2BCA72) : Colors.grey),
                          borderRadius: const BorderRadius.only(
                            topLeft: Radius.circular(25),
                            bottomLeft: Radius.circular(25),
                          ),
                        ),
                        width: 5, // Border width// Border color
                      ),
                    ),
                  ],
                ),
                Text(messageReply!)
              ],
            )
          : Wrap(
              crossAxisAlignment: WrapCrossAlignment.end,
              runAlignment: WrapAlignment.end,
              alignment: WrapAlignment.end,
              spacing: 18,
              children: [
                !isFileFromURL(audioSource)
                    ? Padding(
                        padding: const EdgeInsets.only(top: 1.0, bottom: 1.0),
                        child: isLoading
                            ? const AudioPlaceHolder(error: false)
                            : VoiceMessage(
                                audioSrc: audioSource,
                                onPlay: () => {},
                                isSender: isMe,
                                senderBgColor: senderBgColor,
                                receiverBgColor: receiverBgColor,
                                statusAndTime: Padding(
                                  padding: const EdgeInsets.only(bottom: 0.0),
                                  child: SeenStatus(
                                    isMe: isMe,
                                    time: time,
                                    dateTextColor: timeLabelColor,
                                    messageAck: ack,
                                  ),
                                ),
                              ),
                      )
                    : Padding(
                        padding: const EdgeInsets.only(top: 1.0, bottom: 1.0),
                        child: isLoading
                            ? const AudioPlaceHolder(error: false)
                            : FutureBuilder(
                                future: DefaultCacheManager()
                                    .getSingleFile(audioSource),
                                builder: (context, snapshot) {
                                  if (snapshot.connectionState ==
                                      ConnectionState.done) {
                                    if (snapshot.hasError) {
                                      return const AudioPlaceHolder(
                                          error: true);
                                    }
                                    final cachedAudioFile = snapshot.data;
                                    return VoiceMessage(
                                      audioSrc: cachedAudioFile!.path,
                                      onPlay: () => {},
                                      isSender: isMe,
                                      senderBgColor: senderBgColor,
                                      receiverBgColor: receiverBgColor,
                                      statusAndTime: Padding(
                                        padding:
                                            const EdgeInsets.only(bottom: 0.0),
                                        child: SeenStatus(
                                          isMe: isMe,
                                          time: time,
                                          dateTextColor: timeLabelColor,
                                          messageAck: ack,
                                        ),
                                      ),
                                    );
                                  } else {
                                    // Show loading indicator while caching.
                                    return const AudioPlaceHolder(error: false);
                                  }
                                },
                              )),
              ],
            ),
    );
  }
}

==> vengamo_chat_ui-1.4.2.tar.gz: lib/components/audio_widget.dart <==
import 'package:flutter/material.dart';
import 'package:vengamo_chat_ui/components/voice_wave/voice_message.dart';
import '../seen_status.dart';
import '../theme/app_color.dart';
import 'audio_placeholder.dart';
// ignore: depend_on_referenced_packages
import 'package:flutter_cache_manager/flutter_cache_manager.dart';

class AudioWidget extends StatelessWidget {
  const AudioWidget(
      {super.key,
      required this.isMe,
      required this.audioSource,
      required this.ack,
      required this.time,
      required this.timeLabelColor,
      required this.senderBgColor,
      required this.receiverBgColor,
      required this.isLoading,
      this.messageReplyBgColor,
      this.messageReplyBorderColor,
      required this.messageReply,
      this.textStyle});

  final bool isMe;
  final String audioSource;
  final Widget ack;
  final String time;
  final Color timeLabelColor;
  final Color senderBgColor;
  final Color receiverBgColor;
  final bool isLoading;
  final Color? messageReplyBgColor;

  /// style that will be applied on text;
  final TextStyle? textStyle;

  /// the Border color applied to the message reply
  final Color? messageReplyBorderColor;

  /// message Reply
  final Widget? messageReply;

  bool isFileFromURL(String filePath) {
    if (filePath.startsWith('http://') || filePath.startsWith('https://')) {
      return true; //From URL
    } else {
      // local cached file
      return false;
    }
  }

  @override
  Widget build(BuildContext context) {
    return Padding(
      key: key,
      padding: const EdgeInsets.symmetric(horizontal: 8, vertical: 4),
      child: messageReply != null
          ? Column(
              mainAxisAlignment: MainAxisAlignment.start,
              crossAxisAlignment: CrossAxisAlignment.start,
              children: [
                Stack(
                  children: [
                    Container(
                      decoration: BoxDecoration(
                        color: messageReplyBgColor ??
                            (isMe
                                ? const Color(0xFFB3D19D).withOpacity(0.5)
                                : Colors.grey[300]),
                      ),
                      constraints: const BoxConstraints(maxHeight: 55),
                      child: Padding(
                        padding: const EdgeInsets.only(
                            left: 8, top: 3, bottom: 2, right: 2),
                        child: Row(
                          crossAxisAlignment: CrossAxisAlignment.start,
                          mainAxisAlignment: MainAxisAlignment.spaceBetween,
                          children: [
                            Column(
                              crossAxisAlignment: CrossAxisAlignment.start,
                              children: [
                                Text(isMe ? "Sent" : "Received"), // "Sent" text
                                const SizedBox(
                                    height:
                                        8), // Add space between "Sent" and photo icon
                                const Icon(
                                  Icons.mic_sharp,
                                  color: AppColors.iconColor,
                                ), // Photo icon
                              ],
                            ),
                            const SizedBox(
                                width:
                                    8), // Add space between photo icon and image

                            Padding(
                              padding: const EdgeInsets.all(8.0),
                              child: Center(
                                child: Container(
                                  decoration: BoxDecoration(
                                    shape: BoxShape.circle,
                                    color: isMe
                                        ? const Color.fromARGB(
                                            255, 175, 173, 173)
                                        : const Color(0xFF2BCA72),
                                  ),
                                  width: 35,
                                  height: 35,
                                  child: InkWell(
                                    onTap: () => {},
                                    child: Icon(
                                      Icons.play_arrow,
                                      color: messageReplyBorderColor ??
                                          (isMe
                                              ? senderBgColor
                                              : receiverBgColor),
                                      size: 25,
                                    ),
                                  ),
                                ),
                              ),
                            )
                            // The actual photo on the right
                          ],
                        ),
                      ),
                    ),
                    Positioned(
                      top: 0,
                      bottom: 0,
                      left: -1.5, // Adjust the value as needed for your design
                      child: Container(
                        decoration: BoxDecoration(
                          color: messageReplyBorderColor ??
                              (isMe ? const Color(0xFF2BCA72) : Colors.grey),
                          borderRadius: const BorderRadius.only(
                            topLeft: Radius.circular(25),
                            bottomLeft: Radius.circular(25),
                          ),
                        ),
                        width: 5, // Border width// Border color
                      ),
                    ),
                  ],
                ),
                Row(
                  crossAxisAlignment: CrossAxisAlignment.end,
                  children: [
                    Expanded(
                      child: messageReply ?? Container(),
                    ),
                    Align(
                      alignment: Alignment.bottomRight,
                      child: Padding(
                        padding: const EdgeInsets.only(bottom: 0.0),
                        child: SeenStatus(
                          isMe: isMe,
                          time: time,
                          dateTextColor: timeLabelColor,
                          messageAck: ack,
                        ),
                      ),
                    ),
                  ],
                )
              ],
            )
          : Wrap(
              crossAxisAlignment: WrapCrossAlignment.end,
              runAlignment: WrapAlignment.end,
              alignment: WrapAlignment.end,
              spacing: 18,
              children: [
                !isFileFromURL(audioSource)
                    ? Padding(
                        padding: const EdgeInsets.only(top: 1.0, bottom: 1.0),
                        child: isLoading
                            ? const AudioPlaceHolder(error: false)
                            : VoiceMessage(
                                audioSrc: audioSource,
                                onPlay: () => {},
                                isSender: isMe,
                                senderBgColor: senderBgColor,
                                receiverBgColor: receiverBgColor,
                                statusAndTime: Padding(
                                  padding: const EdgeInsets.only(bottom: 0.0),
                                  child: SeenStatus(
                                    isMe: isMe,
                                    time: time,
                                    dateTextColor: timeLabelColor,
                                    messageAck: ack,
                                  ),
                                ),
                              ),
                      )
                    : Padding(
                        padding: const EdgeInsets.only(top: 1.0, bottom: 1.0),
                        child: isLoading
                            ? const AudioPlaceHolder(error: false)
                            : FutureBuilder(
                                future: DefaultCacheManager()
                                    .getSingleFile(audioSource),
                                builder: (context, snapshot) {
                                  if (snapshot.connectionState ==
                                      ConnectionState.done) {
                                    if (snapshot.hasError) {
                                      return const AudioPlaceHolder(
                                          error: true);
                                    }
                                    final cachedAudioFile = snapshot.data;
                                    return VoiceMessage(
                                      audioSrc: cachedAudioFile!.path,
                                      onPlay: () => {},
                                      isSender: isMe,
                                      senderBgColor: senderBgColor,
                                      receiverBgColor: receiverBgColor,
                                      statusAndTime: Padding(
                                        padding:
                                            const EdgeInsets.only(bottom: 0.0),
                                        child: SeenStatus(
                                          isMe: isMe,
                                          time: time,
                                          dateTextColor: timeLabelColor,
                                          messageAck: ack,
                                        ),
                                      ),
                                    );
                                  } else {
                                    // Show loading indicator while caching.
                                    return const AudioPlaceHolder(error: false);
                                  }
                                },
                              )),
              ],
            ),
    );
  }
}
